editables: Editable installations
=================================

Description
-----------

Editable installations

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/editables/

